# -*- coding: utf-8 -*-

__all__ = []

__author__ = "Avi Vajpeyi"
__email__ = "avi.vajpeyi@gmail.com"
__uri__ = "https://github.com/avivajpeyi/aas_job_register_downloader"
__license__ = "MIT"
__description__ = "All the TESS exoplanets!"
__copyright__ = "Copyright 2021 AJRD developers"
__contributors__ = "https://github.com/avivajpeyi/aas_job_register_downloader/graphs/contributors"
